@@ -171,10 +171,6 @@ class Test_EnumException(unittest.TestCase):
                 min_args = 1,
                 types = (enum.EnumException, TypeError),
             ),
-            enum.EnumValueCompareError: dict(
-                min_args = 2,
-                types = (enum.EnumException, AssertionError),
-            ),
         }
 
         for exc_type, params in self.valid_exceptions.items():
